@@ -1,6 +1,5 @@
-# import ConsoleHelp as window
-# window.ysn()
-import time, sys, os
+import time, sys, os, random
+import getpass
 BLACK = '\033[30m'
 RED = '\033[31m'
 GREEN = '\033[32m'
@@ -48,6 +47,7 @@ def printcyan(text):
   print(CYAN + text + RESET)
 def printunderline(text):
   print(UNDERLINE + text + RESET)
+
 def sp(text):
   for char in text:
     print(char, end = "")
@@ -55,11 +55,14 @@ def sp(text):
     sys.stdout.flush()
 def clear():
   print("\033c", end = "")
+
 class color():
   def spc(text,color = None): # put try statement
+      sun = 0
       if color == None:
-        print("Please fill out the color text box")
-      elif color == 'red':
+        print("Please do fill out the color text box")
+        sun = 1  
+      elif color == "red":
         for char in text:
           print(RED + char, end = "")
           time.sleep(0.05)
@@ -102,6 +105,9 @@ class color():
       else:
         print(f'Error: unknown text formatting: {color}')
 class math():
+  def rand(num1, num2):
+    raand = random.randint(int(num1), int(num2))
+    return raand
   def add(num1, num2):
     try:
       float(num1)
@@ -170,11 +176,24 @@ class math():
           print("ERROR")
     except:
       print("ERROR")
-  
-  
-def out(text ,end = None):
-  if end == None:
-    end = "\n"
-  else:
-    pass
-  print(text, end = str(end))
\ No newline at end of file
+
+class user():
+  def password(text):
+    x = getpass.getpass(text)
+    return x
+  def getowner():
+    name = os.environ["REPL_OWNER"]
+    return name
+  def getcmds():
+    print("cmds: WE HAVE NONE, THIS IS A PIP MODULE WUT DO YOU MEANNNN USER.")#oh. ok then. lol
+
+class AllInfo():
+  def getversion():
+    print("VERSION 0.4.7")
+  def getcreators():
+    print("CREATOR\MOD: darkdarcool\nWEIRD SIDEKICK(maybe maintaner if you wanna call it that smth): JBloves27")#yasssss 
+  def getupdates():
+    pass # for the future yes 
+  def getlanguage():#idk
+    print("MСіз англияда жасалған деп ойлайсыз ба?") # there you go
+  
\ No newline at end of file
